_G.DMCCC = _G.DMCCC or {}
DMCCC._path = ModPath
DMCCC._data_path = SavePath .. "DMCCC.txt"
DMCCC._options_path = DMCCC._path .. "/options/options.json"
DMCCC._data = {} 

function DMCCC:Save()
	local file = io.open( self._data_path, "w+" )
	if file then
		file:write( json.encode( self._data ) )
		file:close()
	end
end

function DMCCC:Load()
	local file = io.open( self._data_path, "r" )
	if file then
		self._data = json.decode( file:read("*all") )
		file:close()
	end
	DMCCC:LoadDefaults()
end

function DMCCC:LoadDefaults()
	-- sets default vals in .data with default_value from menujson WHEN MISSING
	local file = io.open(self._options_path, "r")
	if file then
		local file_content = file:read("*all")
		file:close()
		local content = json.decode(file_content)
		local items = content.items

		for _ , item in pairs(items) do
			if not self._data[item.value] then
				self._data[item.value] = item.default_value
			end
		end
	end
end
DMCCC:LoadDefaults()
log("[DMCCC] : DMCCC Initialized")

function DMCCC:GetOption(id)
	return self._data[id]
end

Hooks:Add("LocalizationManagerPostInit", "LocalizationManagerPostInit_DMCCC", function( loc )
	local localization = DMCCC._path .. "loc/"
	local GetFiles = _G.file.GetFiles
	local Idstring = _G.Idstring
	local activelanguagekey = SystemInfo:language():key()
	for __, filename in ipairs(GetFiles(localization)) do
		if Idstring(filename:match("^(.*).json$") or ""):key() == activelanguagekey then
			loc:load_localization_file(localization .. filename)
			break
		end
	end
	loc:load_localization_file(localization .. "english.json", false)
end)

Hooks:Add( "MenuManagerInitialize", "MenuManagerInitialize_DMCCC", function( menu_manager )
	MenuCallbackHandler.callback_panel_x = function(self, item)
		DMCCC._data.panel_x = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_panel_y = function(self, item)
		DMCCC._data.panel_y = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_panel_w = function(self, item)
		DMCCC._data.panel_w = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_panel_h = function(self, item)
		DMCCC._data.panel_h = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_d_kills = function(self, item)
		DMCCC._data.rank_d_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_c_kills = function(self, item)
		DMCCC._data.rank_c_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_b_kills = function(self, item)
		DMCCC._data.rank_b_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_a_kills = function(self, item)
		DMCCC._data.rank_a_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_s_kills = function(self, item)
		DMCCC._data.rank_s_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_ss_kills = function(self, item)
		DMCCC._data.rank_ss_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_sss_kills = function(self, item)
		DMCCC._data.rank_sss_kills = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_kill_timer = function(self, item)
		DMCCC._data.kill_timer = item:value()
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_sounds = function(self, item)
		DMCCC._data.rank_sounds = item:value() == 'on'
		DMCCC:Save()
	end
	MenuCallbackHandler.callback_rank_volume = function(self, item)
		DMCCC._data.rank_volume = item:value()
		DMCCC:Save()
	end
	DMCCC:Load()
	MenuHelper:LoadFromJsonFile( DMCCC._path .. "options/options.json", DMCCC, DMCCC._data )
end )